#
# spec file for package python3-rdflib-doc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-rdflib-doc
Version:        4.2.1
Release:        1.5
Summary:        Documentation for python3-rdflib
License:        BSD-3-Clause
Group:          Documentation/HTML
Url:            http://rdflib.net/
Source:         https://files.pythonhosted.org/packages/source/r/rdflib/rdflib-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python3-rdflib = %{version}
BuildRequires:  python3-Sphinx
Recommends:     python3-rdflib = %{version}
BuildArch:      noarch

%description
Documentation and help files for python3-rdflib.

%prep
%setup -q -n rdflib-%{version}
sed -i "1d" rdflib/plugins/parsers/{ntriples,notation3}.py # Fix non-executable bits
# Drop py2.7 bytecode files, we have to rebuild these:
find . -type f -name "*.pyc" -print -delete

%build
cd docs
make html
# Remove hidden file
rm -r _build/html/.buildinfo

%install
# fix end-of-line encoding
sed -i 's/\r$//' docs/_build/html/_static/jquery.js

%fdupes -s docs/_build/html

%files
%defattr(-,root,root)
%doc docs/_build/html

%changelog
* Thu May 19 2016 toddrme2178@gmail.com
- Split documentation into own subpackage to speed up build.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Mon Mar 14 2016 schwab@suse.de
- Remove python3-SPARQLWrapper from BuildRequires to break build cycle
* Fri Oct 30 2015 toddrme2178@gmail.com
- Disable testing-only requirements
- python3-flake8 is only needed during testing, not at runtime.
  So remove it as a Requires.
* Thu Oct 29 2015 toddrme2178@gmail.com
- Disable tests, they don't work properly on python 3.x.
* Tue Oct  6 2015 arun@gmx.de
- specfile:
  * added networkx for tests
- update to version 4.2.1:
  * Added a Networkx connector #471, #507
  * Added a graph_tool connector #473
  * Added a graphs method to the Dataset object #504, #495
  * Batch commits for SPARQLUpdateStore #486
  * Fixed bnode collision bug #506, #496, #494
  * fix util.from_n3() parsing Literals with datatypes and Namespace
    support #503, #502
  * make Identifier.__hash__ stable wrt. multi processes #501, #500
  * fix handling URLInputSource without content-type #499, #498
  * no relative import in algebra when run as a script #497
  * Duplicate option in armstrong theme.conf removed #491
  * Variable.__repr__ returns a python representation string, not n3
    [#488]
  * fixed broken example #482
  * trig output fixes #480
  * set PYTHONPATH to make rdfpipe tests use the right rdflib version
    [#477]
  * fix RDF/XML problem with unqualified use of rdf:about #470, #468
  * AuditableStore improvements #469, #463
  * added asserts for graph.set([s,p,o]) so s and p aren't None #467
  * threading.RLock instances are context managers #465
  * SPARQLStore does not transform Literal('') into Literal('None')
    anymore #459, #457
  * slight performance increase for graph.all_nodes() #458
  * travis: migrate to docker container infrastructure #508
  * test for narrow python builds (chars > 0xFFFF) (related to #453,
    [#454] ) #456, #509
  * dropped testing py3.2 #448
  * Running a local fuseki server on travis and making it failsafe
    [#476], #475, #474, #466, #460
  * exclude def main(): functions from test coverage analysis #472
* Thu Jul  9 2015 toddrme2178@gmail.com
- Make update-alternatives compatible with python-rdflib
* Wed Jul  1 2015 toddrme2178@gmail.com
- Add group field to doc
* Wed Jul  1 2015 toddrme2178@gmail.com
- Split documentation into doc subpackage
- Don't build documentation for SLES 12
  python-Sphinx is not available on SLES 12,
  and python3-Sphinx won't work until this issue is fixed:
  https://github.com/RDFLib/rdflib/issues/491
* Fri Feb 20 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.2.0:
* Thu Sep 11 2014 toddrme2178@gmail.com
- Update to 4.1.2
  * This is a bug-fix release.
  * Fixed unicode/str bug in py3 for rdfpipe
    [#375](https://github.com/RDFLib/rdflib/issues/375)
- Update to 4.1.1
  * This is a bug-fix release.
  * This will be the last RDFLib release to support python 2.5.
  * The RDF/XML Parser was made stricter, now raises exceptions for
    illegal repeated node-elements.
    [#363](https://github.com/RDFLib/rdflib/issues/363)
  * The SPARQLUpdateStore now supports non-ascii unicode in update
    statements
    [#356](https://github.com/RDFLib/rdflib/issues/356)
  * Fixed a bug in the NTriple/NQuad parser wrt. to unicode escape sequences
    [#352](https://github.com/RDFLib/rdflib/issues/352)
  * HTML5Lib is no longer pinned to 0.95
    [#355](https://github.com/RDFLib/rdflib/issues/360)
  * RDF/XML Serializer now uses parseType=Literal for well-formed XML literals
  * A bug in the manchester OWL syntax was fixed
    [#355](https://github.com/RDFLib/rdflib/issues/355)
- Update to 4.1
  * This is a new minor version RDFLib, which includes a handful of new features:
  * A TriG parser was added (we already had a serializer) - it is
    up-to-date wrt. to the newest spec from: http://www.w3.org/TR/trig/
  * The Turtle parser was made up to date wrt. to the latest Turtle spec.
  * Many more tests have been added - RDFLib now has over 2000
    (passing!) tests. This is mainly thanks to the NT, Turtle, TriG,
    NQuads and SPARQL test-suites from W3C. This also included many
    fixes to the nt and nquad parsers.
  * ```ConjunctiveGraph``` and ```Dataset``` now support directly adding/removing
    quads with ```add/addN/remove``` methods.
  * ```rdfpipe``` command now supports datasets, and reading/writing context
    sensitive formats.
  * Optional graph-tracking was added to the Store interface, allowing
    empty graphs to be tracked for Datasets. The DataSet class also saw
    a general clean-up, see: [#309](https://github.com/RDFLib/rdflib/pull/309)
  * After long deprecation, ```BackwardCompatibleGraph``` was removed.
  * Minor enhancements/bugs fixed:
  * Many code samples in the documentation were fixed thanks to @PuckCh
  * The new ```IOMemory``` store was optimised a bit
  * ```SPARQL(Update)Store``` has been made more generic.
  * MD5 sums were never reinitialized in ```rdflib.compare```
  * Correct default value for empty prefix in N3
    [#312](https://github.com/RDFLib/rdflib/issues/312)
  * Fixed tests when running in a non UTF-8 locale
    [#344](https://github.com/RDFLib/rdflib/issues/344)
  * Prefix in the original turtle have an impact on SPARQL query
    resolution
    [#313](https://github.com/RDFLib/rdflib/issues/313)
  * Duplicate BNode IDs from N3 Parser
    [#305](https://github.com/RDFLib/rdflib/issues/305)
  * Use QNames for TriG graph names
    [#330](https://github.com/RDFLib/rdflib/issues/330)
  * \uXXXX escapes in Turtle/N3 were fixed
    [#335](https://github.com/RDFLib/rdflib/issues/335)
  * A way to limit the number of triples retrieved from the
    ```SPARQLStore``` was added
    [#346](https://github.com/RDFLib/rdflib/pull/346)
  * Dots in localnames in Turtle
    [#345](https://github.com/RDFLib/rdflib/issues/345)
    [#336](https://github.com/RDFLib/rdflib/issues/336)
  * ```BNode``` as Graph's public ID
    [#300](https://github.com/RDFLib/rdflib/issues/300)
  * Introduced ordering of ```QuotedGraphs```
    [#291](https://github.com/RDFLib/rdflib/issues/291)
* Fri Dec  6 2013 toddrme2178@gmail.com
- Update to 4.0.1
  * Bugfixes
- Update to 4.0
  * The new SPARQL 1.1 engine (rdflib-sparql) has been included in the core distribution. SPARQL 1.1 queries and updates should work out of the box.
  * Several RDF 1.1 features are available:
  * A new DataSet class
  * XMLLiteral and HTMLLiterals
  * BNode (de)skolemization is supported through BNode.skolemize, URIRef.de_skolemize, Graph.skolemize and Graph.de_skolemize
  * Handled of Literal equality was split into lexical comparison (for normal == operator) and value space (using new Node.eq methods). This introduces some slight backwards incomaptible changes, but was necessary, as the old version had inconsisten hash and equality methods that could lead the literals not working correctly in dicts/sets. The new way is more in line with how SPARQL 1.1 works. For the full details, see:
  * Iterating over QueryResults will generate ResultRow objects, these allow access to variable bindings as attributes or as a dict. I.e.
  * "Slicing" of Graphs and Resources as syntactic sugar: (#271)
  * The SPARQLStore and SPARQLUpdateStore are now included in the RDFLib core
  * The documentation has been given a major overhaul, and examples for most features have been added.
- Update to 3.4
  * This release introduced new parsers for structured data in HTML. In particular formats: hturtle, rdfa, mdata and an auto-detecting html format were added. Thanks to Ivan Herman for this!
  * This release includes a lot of admin maintentance - correct dependencies for different python versions, etc. Several py3 bugs were also fixed.
  * This release drops python 2.4 compatability - it was just getting too expensive for us to maintain. It should however be compatible with any cpython from 2.5 through 3.3.
  * node.md5_term is now deprecated, if you use it let us know.
- Add additional dependencies
- Implement update-alternatives
* Fri Apr 12 2013 toddrme2178@gmail.com
- Disable building for python3 <= 3.2, since it is not compatible
  with those versions
* Thu Jan 31 2013 saschpe@suse.de
- Drop shipped bytecode files and recompile them
* Wed Jan 30 2013 saschpe@suse.de
- Run testsuite everywhere
* Sun Jan 13 2013 p.drouand@gmail.com
- Initial python3 support
